@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/Mesh_3/include/CGAL/IO/File_avizo.h $
+// $Id: File_avizo.h ba3a59e 2017-11-30T15:54:00+01:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: GPL-3.0+
 //
 //
 // Author(s)     : Laurent Rineau
@@ -46,7 +47,7 @@ output_to_avizo(std::ostream& os,
   typedef typename Tr::Finite_vertices_iterator Finite_vertices_iterator;
   typedef typename Tr::Vertex_handle Vertex_handle;
   typedef typename Tr::Cell_handle Cell_handle;
-  typedef typename Tr::Point Point_3;
+  typedef typename Tr::Weighted_point Weighted_point;
 
   const Tr& tr = c3t3.triangulation();
 
@@ -105,7 +106,7 @@ output_to_avizo(std::ostream& os,
         end = tr.finite_vertices_end();
       vit != end; ++vit)
   {
-    const Point_3& p = vit->point();
+    const Weighted_point& p = tr.point(vit);
     const double x = CGAL::to_double(p.x());
     const double y = CGAL::to_double(p.y());
     const double z = CGAL::to_double(p.z());
