@@ -13,8 +13,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/Mesh_3/include/CGAL/Mesh_3/io_signature.h $
+// $Id: io_signature.h d82cdbc 2018-10-05T17:02:38+02:00 Laurent Rineau
 // SPDX-License-Identifier: GPL-3.0+
 //
 // Author(s)     : Laurent RINEAU
@@ -35,23 +35,30 @@
 #include <CGAL/Triangulation_cell_base_with_info_3.h>
 #include <CGAL/Regular_triangulation_3.h>
 #include <CGAL/Regular_triangulation_cell_base_3.h>
+#include <CGAL/Regular_triangulation_cell_base_with_weighted_circumcenter_3.h>
+
+#ifdef CGAL_PERIODIC_3_MESH_3_CONFIG_H
+#include <CGAL/Periodic_3_triangulation_3.h>
+#include <CGAL/Periodic_3_regular_triangulation_3.h>
+#endif
+
 #include <boost/variant.hpp>
 #include <boost/tuple/tuple.hpp>
 #include <utility>
 
-namespace CGAL { 
+namespace CGAL {
 
 // SFINAE test
 template <typename T, typename U>
 class has_io_signature
 {
 private:
-	template <U> struct helper;
-	template <typename V> static char check(helper<&V::io_signature> *);
-	template <typename V> static char (&check(...))[2];
+  template <U> struct helper;
+  template <typename V> static char check(helper<&V::io_signature> *);
+  template <typename V> static char (&check(...))[2];
 
 public:
-	enum { value = (sizeof(check<T>(0)) == sizeof(char)) };
+  enum { value = (sizeof(check<T>(0)) == sizeof(char)) };
 };
 
 template <class T, bool has_io_signature>
@@ -68,6 +75,7 @@ struct Get_io_signature_aux<T, false>
 {
   std::string operator()() const
   {
+    std::cerr << "Type without signature: " << typeid(T).name() << std::endl;
     return std::string();
   }
 }; // end template partial specialization Get_io_signature_aux<T, false>
@@ -101,6 +109,46 @@ struct Get_io_signature<unsigned int>
   }
 };
 
+template <>
+struct Get_io_signature<char>
+{
+  std::string operator()() {
+    return "c";
+  }
+};
+
+template <>
+struct Get_io_signature<unsigned char>
+{
+  std::string operator()() {
+    return "uc";
+  }
+};
+
+template <>
+struct Get_io_signature<signed char>
+{
+  std::string operator()() {
+    return "sc";
+  }
+};
+
+template <>
+struct Get_io_signature<short int>
+{
+  std::string operator()() {
+    return "s";
+  }
+};
+
+template <>
+struct Get_io_signature<unsigned short int>
+{
+  std::string operator()() {
+    return "us";
+  }
+};
+
 template <>
 struct Get_io_signature<double>
 {
@@ -150,7 +198,7 @@ struct Get_io_signature<boost::variant<T,U,V> >
   }
 };
 
-template <typename T, typename U, 
+template <typename T, typename U,
           typename V, typename W>
 struct Get_io_signature<boost::variant<T,U,V,W> >
 {
@@ -198,7 +246,7 @@ Get_io_signature<Triangulation_3<Gt, Triangulation_data_structure_3<Vb, Cb, C_ta
 
 #ifdef CGAL_DELAUNAY_TRIANGULATION_3_H
 template <class Gt, class Tds>
-struct 
+struct
 Get_io_signature<Delaunay_triangulation_3<Gt, Tds> >
 {
   std::string operator()() {
@@ -218,6 +266,32 @@ Get_io_signature<Regular_triangulation_3<Gt, Tds> >
 };
 #endif
 
+#ifdef CGAL_PERIODIC_3_TRIANGULATION_3_H
+template <class Gt, class Tds>
+struct
+Get_io_signature<Periodic_3_triangulation_3<Gt, Tds> >
+{
+  std::string operator()() {
+    return std::string("Periodic_3_triangulation_3(") +
+      Get_io_signature<typename Tds::Vertex::Point>()() +
+      ",Vb(" + Get_io_signature<typename Tds::Vertex>()() +
+      "),Cb(" + Get_io_signature<typename Tds::Cell>()() +
+      "))";
+  }
+};
+#endif
+
+#ifdef CGAL_PERIODIC_3_REGULAR_TRIANGULATION_3_H
+template <class Gt, class Tds>
+struct
+Get_io_signature<Periodic_3_regular_triangulation_3<Gt, Tds> >
+{
+  std::string operator()() {
+    return Get_io_signature<Periodic_3_triangulation_3<Gt, Tds> >()();
+  }
+};
+#endif
+
 #ifdef CGAL_TRIANGULATION_VERTEX_BASE_3_H
 template <class Gt, class Vb>
 struct Get_io_signature<Triangulation_vertex_base_3<Gt, Vb> >
@@ -283,6 +357,17 @@ Get_io_signature<Regular_triangulation_cell_base_3<Gt, Cb, Container> >
 };
 #endif
 
+#ifdef CGAL_REGULAR_TRIANGULATION_CELL_BASE_WITH_CIRCUMCENTER_3_H
+template <class Gt, class Cb>
+struct
+Get_io_signature<Regular_triangulation_cell_base_with_weighted_circumcenter_3<Gt, Cb> >
+{
+  std::string operator()() {
+    return "RTWWCcb_3";
+  }
+};
+#endif
+
 } // end namespace CGAL
 
 
